@@ -104,13 +104,11 @@ def get_one_vec(**kwargs):
     is_lite = kwargs.get('is_lite', '0')
 
     vecs = text2vec(text)
-    vecs = normalize(vecs)
 
-    if is_lite == '0':
-        return vecs.tolist()
-    else:
-        vecs = vecs[:, range(0, 768, 4)]
-        return normalize(vecs).tolist()  # 64*3 = 192维度
+    if is_lite == '1':
+        vecs = vecs[:, range(0, 768, 4)]  # 64*3 = 192维度
+
+    return normalize(vecs).tolist()
 
 
 def get_batch_vec(**kwargs):
